function [y,yh,H,HH,G,Gh]=dualtreeM1D_freq(x,M,rm)

%function [wp,wm,H,HH,G,Gh]=dualtreeM1D_freq(x,M,rm)
%Program of 1D DTT decomposition
%INPUT;
%   x : signal to decompose
%   M : filter tu use (see readme file)
%   rm : nb of decomposition levels
%OUTPUT:
%   y : primal tree coef
%   yh : dual tree coef
%   conj(H): filters used for decomposition
%   conj(HH): Hilbert filters used for decomposition
%   G: prefilter used for decomposition
%   Gh: Dual prefilter used for decomposition


%*****************************************************
%* author: Caroline Chaux                            *
%* institution: Institut Gaspard Monge - CNRS	     *
%*	       Universit de Marne la Valle             *
%* date: Thursday, November, 2nd 2006                *
%* License CeCILL-B				      *
%*****************************************************



if M==2
    M=2;
    ep=1/5;
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    om = (0:LX-1)*2*pi/LX;
    H = fr2bandmeyer(om,ep);
    m='M2';
elseif M == 3
    M=3;
    ep = 1/7;
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    om = (0:LX-1)*2*pi/LX;
    H = fr3bandmeyer(om,ep);
    m='M3';
elseif M == 4
    M=4;
    ep = 1/9;
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    om = (0:LX-1)*2*pi/LX;
    H = fr4bandmeyer(om,ep);
    m='M4';
elseif strcmp(M,'article')
    M=4;
    [sf,af]=filters('article');
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    af1=[af(size(af,1)/2+1:end,:);zeros(LX-size(af,1),4);af(1:size(af,1)/2,:)];
    H = (fft(af1)).';
    m='article';
elseif strcmp(M,'MLT8')
    M=8;
    [sf,af]=filters('MLT8');
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    af1=[af(size(af,1)/2+1:end,:);zeros(LX-size(af,1),8);af(1:size(af,1)/2,:)];
    H = (fft(af1)).';
    m='MLT8';
elseif strcmp(M,'MLT4')
    M=4;
    [sf,af]=filters('MLT4');
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    af1=[af(size(af,1)/2+1:end,:);zeros(LX-size(af,1),4);af(1:size(af,1)/2,:)];
    H = (fft(af1)).';
    m='MLT4';
elseif strcmp(M,'MLT3')
    M=3;
    [sf,af]=filters('MLT3');
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    af1=[af(size(af,1)/2+1:end,:);zeros(LX-size(af,1),3);af(1:size(af,1)/2,:)];
    H = (fft(af1)).';
    m='MLT3';
elseif strcmp(M,'symlets')
    M=2;
    [sf,af]=filters('symlets');
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    af1=[af(size(af,1)/2+1:end,:);zeros(LX-size(af,1),2);af(1:size(af,1)/2,:)];
    H = (fft(af1)).';
    m='symlets';
elseif strcmp(M,'haar')
    M=2;
    [sf,af]=filters('haar');
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    af1=[af(size(af,1)/2+1:end,:);zeros(LX-size(af,1),2);af(1:size(af,1)/2,:)];
    H = (fft(af1)).';
    m='haar';
elseif strcmp(M,'shannon')
    M=2;
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    [Ht1,Gt1] = gene_pw(LX,'sinc',1);
    H=[Ht1;Gt1];
    m='shannon';
elseif strcmp(M,'shannon4')
    M=4;
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    H=gene_pwMbandes(LX,M);
    m='shannon4';
elseif strcmp(M,'splines')
    M=2;
    x=x(1:M^rm*floor(length(x)/M^rm));
    LX = length(x);
    Ht = frsplis(LX,2);
    Gt = freqcqf(Ht);
    H = [Ht;Gt];
    m='splines';
end




%Definition of Hilbert pairs
HH=hilbert_filters_freq_1D(H);

if rem(LX,M^rm) ~= 0 
    error('Dimensions should be multiple of M^rm');
end


%Prefiltering
[G,Gh]=genere_gamma_freq_1D(M,m,LX);

%normalisation
x=fft(x)/sqrt(LX);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%prefiltering
N=G.*x;
Nh=Gh.*x;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%temporal domain
N=real(ifft(N)*sqrt(LX));
Nh=real(ifft(Nh)*sqrt(LX));


y = Mpdwt(conj(H),N,rm);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%second tree "dual"

yh = Mpdwt(conj(HH),Nh,rm);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


