function Phi=genere_phi_freq_1D(M,m,N)

%function Phi=genere_phi_freq_1D(M,m,N)
%Genere the scaling function Phi in frequential
%INPUT:
%   M : band's number
%   m : filter to use (automatic with the dual tree decomposition)
%   N : image's number points
%OUTPUT :
%   Phi : the scaling function

%*****************************************************
%* author: Caroline Chaux                            *
%* institution: Institut Gaspard Monge - CNRS	     *
%*	       Universit de Marne la Valle             *
%* date: Thursday, November, 2nd 2006                *
%* License CeCILL-B				      *
%*****************************************************


jmax=3;

T=N*M^(jmax-1);

om = (0:T-1)*2*pi/T;

switch m
    case 'M2'
        ep=1/5;
        H = fr2bandmeyer(om,ep);
    case 'M3'
        ep = 1/7;
        H = fr3bandmeyer(om,ep);
    case 'M4'
        ep = 1/9;
        H = fr4bandmeyer(om,ep);
    case 'symlets'
        [sf,af]=filters('symlets');
        af1=[af(size(af,1)/2+1:end,:);zeros(T-size(af,1),2);af(1:size(af,1)/2,:)];
        H = (fft(af1)).';
    case 'article'
        [sf,af]=filters('article');
        af1=[af(size(af,1)/2+1:end,:);zeros(T-size(af,1),4);af(1:size(af,1)/2,:)];
        H = (fft(af1)).';
    case 'MLT8'
        [sf,af]=filters('MLT8');
        af1=[af(size(af,1)/2+1:end,:);zeros(T-size(af,1),8);af(1:size(af,1)/2,:)];
        H = (fft(af1)).';
    case 'MLT4'
        [sf,af]=filters('MLT4');
        af1=[af(size(af,1)/2+1:end,:);zeros(T-size(af,1),4);af(1:size(af,1)/2,:)];
        H = (fft(af1)).';
    case 'MLT3'
        [sf,af]=filters('MLT3');
        af1=[af(size(af,1)/2+1:end,:);zeros(T-size(af,1),3);af(1:size(af,1)/2,:)];
        H = (fft(af1)).';
    case 'haar'
        [sf,af]=filters('haar');
        af1=[af(size(af,1)/2+1:end,:);zeros(T-size(af,1),2);af(1:size(af,1)/2,:)];
        H = (fft(af1)).';
    case 'shannon'
        [Ht1,Gt1] = gene_pw(T,'sinc',1);
        H=[Ht1;Gt1];
    case 'shannon4'
        M=4;
        H=gene_pwMbandes(T,M);
    case 'splines'
        M=2;
        Ht = frsplis(T,2);
        Gt = freqcqf(Ht);
        H = [Ht;Gt];
end


H0=H(1,:).*(1/sqrt(M));
Phi=ones(1,N);

for j=1:jmax,
    Phi=Phi.*H0(1:M^(jmax-j):N*M^(jmax-j));
end


% figure
% plot((0:N-1)*M*2*pi/N,abs(Phi))
% 
